Long-run Covariance Estimation
==============================


Long-run Covariance Estimators
------------------------------

.. module:: arch.covariance.kernel
   :synopsis: Kernel-based long-run covariance estimation

.. currentmodule:: arch.covariance.kernel

.. autosummary::
   :toctree: generated/

   Andrews
   Bartlett
   Gallant
   NeweyWest
   Parzen
   ParzenCauchy
   ParzenGeometric
   ParzenRiesz
   QuadraticSpectral
   TukeyHamming
   TukeyHanning
   TukeyParzen

Results
-------

.. autosummary::
   :toctree: generated/

   CovarianceEstimate
